==> fusenshi-0.7.5.tgz: fusenshi-0.7.5/src/wnd/senddialog.h <==
/*
 * $Id: senddialog.h,v 1.2 2004/11/04 17:39:52 ozawa Exp $
 *
 * Copyright 2003- ONGS Inc. All rights reserved.
 * 
 * author: Masanori OZAWA (ozawa@ongs.co.jp)
 * version: $Revision: 1.2 $
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 *   1. Redistributions of source code must retain the above copyright
 *      notice, this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright
 *      notice, this list of conditions and the following disclaimer in the
 *      documentation and/or other materials provided with the distribution.
 * 
 * THIS SOFTWARE IS PROVIDED BY ONGS INC ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL ONGS INC OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 * The views and conclusions contained in the software and documentation are
 * those of the authors and should not be interpreted as representing official
 * policies, either expressed or implied, of the ONGS Inc.
 * 
 */

#ifndef ___SENDDIALOG_H
#define ___SENDDIALOG_H

#include "gtkmm.h"
#include "../include/serverlist.h"

class SendDialog : public Gtk::Dialog
{
public:
    /**
     * 󥹥ȥ饯
     */
    SendDialog();
    
    /**
     * ǥȥ饯
     */
    virtual ~SendDialog();
    
    /**
     * ꥹȥǥŪ˼ޤ
     */
    Glib::RefPtr<Gtk::ListStore> getListStore();
    
    /**
     * 䵻極аޤ
     * 
     * @return 䵻極а
     */
    ServerList& getServerList();
    
protected:
    /**
     * OKܥ󲡲
     */
    virtual void on_ok_clicked();

    /**
     * ܥ󲡲
     */
    virtual void on_refresh_clicked();
    
    /**
     * 򤷤ޤ
     */
    virtual void on_selected_foreach
        (const Gtk::TreeModel::Path& path, const Gtk::TreeModel::iterator& iter);
    
private:
    /**
     * ݻ饹
     */
    class ModelColumns : public Gtk::TreeModel::ColumnRecord
    {
    public:
        Gtk::TreeModelColumn<Glib::ustring>  USERNAME;
        Gtk::TreeModelColumn<Glib::ustring>  HOSTNAME;
        Gtk::TreeModelColumn<Glib::ustring>  IPADDR;
    
        ModelColumns() { add(USERNAME); add(HOSTNAME); add(IPADDR); }
    };

public:
    /**
     * 
     */
    const ModelColumns m_cColumns;

    /**
     * ɽΥ饤Ȥ
     */
    int m_nClients;

private:
    /**
     * ͥåȥ
     */
    ServerList m_cServerList;
    
    /**
     * ޡֹ
     */
    gint m_nTimer;
    
    /**
     * ĥ꡼ӥ塼
     */
    Gtk::TreeView m_cTreeView;
    
    /**
     * ĥ꡼ӥ塼Υꥹȥǥ
     */
    Glib::RefPtr<Gtk::ListStore> m_cListStore;
};

#endif

==> fusenshi-0.8.2.tgz: fusenshi-0.8.2/src/wnd/senddialog.h <==
/*
 * $Id: senddialog.h,v 1.3 2005/12/02 07:08:01 ozawa Exp $
 *
 * Copyright 2003- ONGS Inc. All rights reserved.
 * 
 * author: Masanori OZAWA (ozawa@ongs.co.jp)
 * version: $Revision: 1.3 $
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 *   1. Redistributions of source code must retain the above copyright
 *      notice, this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright
 *      notice, this list of conditions and the following disclaimer in the
 *      documentation and/or other materials provided with the distribution.
 * 
 * THIS SOFTWARE IS PROVIDED BY ONGS INC ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL ONGS INC OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 * The views and conclusions contained in the software and documentation are
 * those of the authors and should not be interpreted as representing official
 * policies, either expressed or implied, of the ONGS Inc.
 * 
 */

#ifndef ___SENDDIALOG_H
#define ___SENDDIALOG_H

#include "gtkmm.h"
#include "../include/serverlist.h"

class SendDialog : public Gtk::Dialog
{
public:
    /**
     * 󥹥ȥ饯
     */
    SendDialog();
    
    /**
     * ǥȥ饯
     */
    virtual ~SendDialog();
    
    /**
     * ꥹȥǥŪ˼ޤ
     */
    Glib::RefPtr<Gtk::ListStore> getListStore();
    
    /**
     * 䵻極аޤ
     * 
     * @return 䵻極а
     */
    ServerList& getServerList();
    
protected:
    /**
     * OKܥ󲡲
     */
    virtual void on_ok_clicked();

    /**
     * ܥ󲡲
     */
    virtual void on_refresh_clicked();
    
    /**
     * 򤷤ޤ
     */
    virtual void on_selected_foreach
        (const Gtk::TreeModel::Path& path, const Gtk::TreeModel::iterator& iter);
    
private:
    /**
     * ݻ饹
     */
    class ModelColumns : public Gtk::TreeModel::ColumnRecord
    {
    public:
        Gtk::TreeModelColumn<Glib::ustring>  USERNAME;
        Gtk::TreeModelColumn<Glib::ustring>  HOSTNAME;
        Gtk::TreeModelColumn<Glib::ustring>  IPADDR;
        Gtk::TreeModelColumn<bool>          SSL;
        Gtk::TreeModelColumn<u_int32_t>      EXTINFO;
    
        ModelColumns() { add(USERNAME); add(HOSTNAME); add(IPADDR); add(SSL); add(EXTINFO); }
    };

public:
    /**
     * 
     */
    const ModelColumns m_cColumns;

    /**
     * ɽΥ饤Ȥ
     */
    int m_nClients;

private:
    /**
     * ͥåȥ
     */
    ServerList m_cServerList;
    
    /**
     * ޡֹ
     */
    gint m_nTimer;
    
    /**
     * ĥ꡼ӥ塼
     */
    Gtk::TreeView m_cTreeView;
    
    /**
     * ĥ꡼ӥ塼Υꥹȥǥ
     */
    Glib::RefPtr<Gtk::ListStore> m_cListStore;
};

#endif
